/********************************************************************************************/
/*                                                                                          */
/*     Funktionen:                                                                          */
/*     seri_init    :=  Initialisierung der seriellen Schnittstelle des CC03ers             */
/*     mw_erf8      :=  Betrieb des ON-Chip A/D-Wandlers, Funktion liefert 8-Bit Ergebnis!  */
/*     mw_erf10     :=  Betrieb des ON-Chip A/D-Wandlers, Funktion liefert 10-Bit Ergebnis! */
/*                                                                                          */
/*                                                                                          */
/*     Zielsystem:        TFH-Core ONE, Prozessor: AT89C51CC03 (Atmel)                      */
/*                                                                                          */
/*                                                                                          */
/*     IDE/C-Compiler:    uC/51 (Wickenhuser)                                              */
/*                                                                                          */
/*     Letzte nderung:   18.12.2007                                                        */
/*                                                                                          */
/*     Datei:             cc03er.c                                                          */
/*                                                                                          */
/********************************************************************************************/

/*** Einbinden von Include-Dateien ***/
#include<at89c51cc03.h>

/********************************************************************************/
/*  Funktion void seri_init(void) initialisiert die serielle Schnittstelle des  */
/*  CC03ers bei einer Taktfrequenz von 11,0592MHz mit nachfolgenden Schnitt-    */
/*  stellen Parametern: 9600 Bd, 1 Stopp-Bit, keine Paritt, asynchr. Betrieb!  */
/********************************************************************************/

void seri_init(void)
  {
    SCON=0x52;
    TMOD |=0x20;
    TH1=0xfd;                      
    TR1=1;
    TI=1;
  }

/********************************************************************************/
/*  Die Funktion unsigned int mw_erf8(unsigned char kanal) dient zum Betrieb    */
/*  des ON-Chip A/D-Wandlers des AT89C51CC03. Der Funktion wird der Eingangs-   */
/*  kanal bergeben und sie liefert ein 8-Bit Wandlungsergebnis als Funktions-  */
/*  wert zurck.                                                                */
/*  Wichtig:        Diese Funktion setzt voraus, das die Grundinitialisierung   */
/*                  des ON-Chip A/D-Wandlers ausserhalb der Funktion, also      */
/*                  z. B. im Hauptprogramm erfolgt. Zur Grundinitialisierung    */
/*                  muss der A/D-Wandler eingeschaltet werden, also das         */
/*                  ADEN-Bit im ADCON SFR gesetz werden ( ADCON = 0x20) und     */
/*                  der zu wandelnde Eingangskanal im SFR ADCF als Analog-      */
/*                  definiert werden (z. B. ADCF = 0xff -> gesamter Port 1      */
/*                  als Analogeingang definiert!                                */
/*  Parameter kanal := Auswahl des A/D-Wandler Eingangskanals (0..7)            */
/********************************************************************************/

unsigned char mw_erf8(unsigned char kanal)
  {      
    ADCON = (ADCON & 0xe8);                 // Kanalauswahl-Bit und Wandlungsende-Bit auf Null setzen!
    ADCON = (ADCON | (0x08+kanal));         // Kanalauswahl und Start der einmaligen Wandlung!
    while((ADCON & 0x10) == 0);             // Warte bis A/D-Wandlung beendet ist!
    return(ADDH);                           // Ergebnisregister auslesen und bergeben!
  }

/********************************************************************************/
/*  Die Funktion unsigned int mw_erf10(unsigned char kanal) dient zum Betrieb   */
/*  des ON-Chip A/D-Wandlers des AT89C51CC03. Der Funktion wird der Eingangs-   */
/*  kanal bergeben und sie liefert ein 10-Bit Wandlungsergebnis als Funktions- */
/*  wert zurck.                                                                */
/*  Wichtig:        Diese Funktion setzt voraus, das die Grundinitialisierung   */
/*                  des ON-Chip A/D-Wandlers ausserhalb der Funktion, also      */
/*                  z. B. im Hauptprogramm erfolgt. Zur Grundinitialisierung    */
/*                  muss der A/D-Wandler eingeschaltet werden, also das         */
/*                  ADEN-Bit im ADCON SFR gesetz werden ( ADCON = 0x20) und     */
/*                  der zu wandelnde Eingangskanal im SFR ADCF als Analog-      */
/*                  definiert werden (z. B. ADCF = 0xff -> gesamter Port 1      */
/*                  als Analogeingang definiert!                                */
/*  Parameter kanal := Auswahl des A/D-Wandler Eingangskanals (0..7)            */
/********************************************************************************/

unsigned int mw_erf10(unsigned char kanal)
  {      
    unsigned int erg;                       // Variable fr 10-Bit Wandlungsergebnis
    ADCON = (ADCON & 0xe8);                 // Kanalauswahl-Bit und Wandlungsende-Bit auf Null setzen!
    ADCON = (ADCON | (0x08+kanal));         // Kanalauswahl und Start der einmaligen Wandlung!
    while((ADCON & 0x10) == 0);             // Warte bis A/D-Wandlung beendet ist!
    erg = ((ADDH << 2) + (ADDL & 0x03));    // Ergebnisregister auslesen u. zusammenbauen!
    return(erg);
  }
